@@ -5,13 +5,15 @@ import os
 from tqdm import tqdm
 
 
-def scan(top_path):
+def scan(top_path, follow_links, follow_mounts):
     prefix_len = len(top_path.rstrip(os.sep)) + 1
     if os.name == 'nt':
         if ':' in top_path:
             prefix_len -= 1  # backslash after drive letter and colon is missing under windows
 
-    for root, dirs, filenames in os.walk(top_path):
+    for root, dirs, filenames in os.walk(top_path, followlinks=follow_links):
+        if not follow_mounts:
+            dirs[:] = filter(lambda d: not os.path.ismount(os.path.join(root, d)), dirs)
         try:
             for filename in filenames:
                 file_path = os.path.join(root, filename)
@@ -20,11 +22,10 @@ def scan(top_path):
             pass
 
 
-def scan_size_tree(root_path):
-    root_path = root_path.rstrip(os.sep)
+def scan_size_tree(root_path, follow_links, follow_mounts):
     size_tree = dict()
-    for path, size in tqdm(scan(root_path), desc=root_path):
-        *directories, filename = path.split(os.sep)
+    for path, size in tqdm(scan(root_path, follow_links, follow_mounts), desc=root_path):
+        *directories, filename = path.lstrip(os.sep).split(os.sep)
         directories.insert(0, root_path)
         current_size_tree = size_tree
         for directory in directories:
